intelmq.bots.experts.geohash package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.geohash package

## Submodules

## intelmq.bots.experts.geohash.expert module

Uses https://pypi.org/project/geolib/ https://github.com/joyanujoy/geolib

intelmq.bots.experts.geohash.expert.BOT

  alias of `intelmq.bots.experts.geohash.expert.GeohashExpertBot`

class intelmq.bots.experts.geohash.expert.GeohashExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Compute the geohash from longitude/latitude information, save it to extra.(source|destination)

  init()
  overwrite: bool = False
  precision: int = 7
  process()

## Module contents